<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtrar:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Escolha o tipo de letra</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Tipo de letra:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Tamanho:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Pré-visualização</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="88"/>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Keep window open when it loses focus</source>
        <translation>Manter a janela aberta quando perder o foco</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Prima %1 para ver o terminal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Limpar terminal ativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>&amp;Next Tab</source>
        <translation>Separador segui&amp;nte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>&amp;Previous Tab</source>
        <translation>Se&amp;parador anterior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>&amp;Previous Tab in History</source>
        <translation>Se&amp;parador anterior no histórico</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>&amp;Next Tab in History</source>
        <translation>Separador segui&amp;nte no histórico</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Move Tab &amp;Left</source>
        <translation>Mover separador para a &amp;esquerda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Move Tab &amp;Right</source>
        <translation>Mover separador para a di&amp;reita</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>Go to</source>
        <translation>Ir para</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Separar na &amp;horizontal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Separar na &amp;vertical</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>Re&amp;colher sub-terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>&amp;Top Subterminal</source>
        <translation>Sub-&amp;terminal superior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>Su&amp;b-terminal inferior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>L&amp;eft Subterminal</source>
        <translation>Sub-terminal &amp;esquerdo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>R&amp;ight Subterminal</source>
        <translation>Sub-terminal &amp;direito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Copy &amp;Selection</source>
        <translation>Copiar &amp;seleção</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Paste Clip&amp;board</source>
        <translation>Colar da área de &amp;transferência</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Paste S&amp;election</source>
        <translation>Colar da s&amp;eleção</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Zoom &amp;in</source>
        <translation>Ampl&amp;iar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Zoom &amp;out</source>
        <translation>Red&amp;uzir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Zoom rese&amp;t</source>
        <translation>&amp;Repor ampliação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>&amp;Find...</source>
        <translation>&amp;Localizar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Handle history...</source>
        <translation>Gestão de histórico...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>&amp;Save Session</source>
        <translation>Guardar &amp;sessão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Carregar sessão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>&amp;Toggle Menu</source>
        <translation>Al&amp;ternar menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="349"/>
        <source>Rename session</source>
        <translation>Renomear sessão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Novo separador</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Novo separador de &amp;pré-ajuste</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 terminais &amp;horizontais</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 terminais &amp;verticais</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 terminai&amp;s</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>&amp;Close Tab</source>
        <translation>Fe&amp;char separador</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nova janela</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="383"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferências...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Ocultar contornos da janela</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>&amp;Show Tab Bar</source>
        <translation>Mo&amp;strar barra de separadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Fullscreen</source>
        <translation>Ecrã completo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Toggle Bookmarks</source>
        <translation>Alternar marcadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Baixo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>&amp;Top</source>
        <translation>&amp;Cima</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>&amp;Right</source>
        <translation>&amp;Direita</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;Left</source>
        <translation>&amp;Esquerda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Posição dos separadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>&amp;None</source>
        <translation>&amp;Nenhuma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Posição da barra de deslo&amp;cação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Bloco</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>&amp;UnderlineCursor</source>
        <translation>S&amp;ublinhado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;Ibeam</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Forma do cursor de teclado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Exit QTerminal</source>
        <translation>Sair do QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Do not ask again</source>
        <translation>Não perguntar novamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Are you sure you want to exit?</source>
        <translation>Tem a certeza de que deseja sair?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>Um emulador de terminal multiplataforma leve e potente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Copyright (C) </source>
        <translation>Direitos de autor (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>2013-2022</source>
        <translation>2013-2022</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <source>LXQt Project</source>
        <translation>Projeto LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Development: </source>
        <translation>Desenvolvimento: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="813"/>
        <source>Emulation</source>
        <translation>Emulação</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Definições do terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="48"/>
        <source>Dropdown</source>
        <translation>Suspenso</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="57"/>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="272"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Ocultar barra de separadores se apenas existir um</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="173"/>
        <source>Color scheme</source>
        <translation>Esquema de cores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="163"/>
        <source>&amp;Change...</source>
        <translation>&amp;Alterar...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="186"/>
        <source>Widget style</source>
        <translation>Estilo do widget</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="199"/>
        <source>Scrollbar position</source>
        <translation>Posição da barra de deslocação</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="212"/>
        <source>Tabs position</source>
        <translation>Posição dos separadores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Show the menu bar</source>
        <translation>Mostrar barra de menu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Show a border around the current terminal</source>
        <translation>Mostrar contornos do terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="354"/>
        <source>Application transparency</source>
        <translation>Transparência da aplicação</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="380"/>
        <source>Terminal transparency</source>
        <translation>Transparência do terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="463"/>
        <source>Start with preset:</source>
        <translation>Iniciar com pré-ajuste:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="474"/>
        <source>None (single terminal)</source>
        <translation>Não (um terminal)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminais horizontais</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="484"/>
        <source>2 terminals vertically</source>
        <translation>2 terminais verticais</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>4 terminals</source>
        <translation>4 terminais</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="127"/>
        <source>Font</source>
        <translation>Tipo de letra</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>Cursor shape</source>
        <translation>Forma do cursor</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="279"/>
        <source>Fixed tab width:</source>
        <translation>Separador com largura fixa:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="497"/>
        <source>Terminal margin</source>
        <translation>Margem do terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Utilizar caracteres de desenho de caixa contidos no tipo de letra</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Os aceleradores são ativados com a tecla Alt e podem interferir com o terminal.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="251"/>
        <source>No menu bar accelerator</source>
        <translation>Não utilizar barra de menu Aceleradores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="614"/>
        <source>Action after paste</source>
        <translation>Ação depois de colar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="644"/>
        <source>Confirm multiline paste</source>
        <translation>Confirmação de colagem</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="651"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Remover início de novas linhas ao colar texto</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="747"/>
        <source>Open new terminals in current working directory</source>
        <translation>Abrir novos terminais no diretório de trabalho atual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="682"/>
        <source>Save Size when closing</source>
        <translation>Guardar tamanho ao fechar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="675"/>
        <source>Save Position when closing</source>
        <translation>Guardar posição ao fechar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="668"/>
        <source>Ask for confirmation when closing</source>
        <translation>Confirmar antes de fechar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="594"/>
        <source>Unlimited history</source>
        <translation>Histórico ilimitado</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="587"/>
        <source>History size (in lines)</source>
        <translation>Limitar histórico (linhas)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="627"/>
        <source>Default $TERM</source>
        <translation>$TERM padrão</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="694"/>
        <source>Start with this size:</source>
        <translation>Iniciar com este tamanho:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Background mode:</source>
        <translation>Modo de fundo:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="440"/>
        <source>Stretch</source>
        <translation>Esticar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Zoom</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="450"/>
        <source>Fit</source>
        <translation>Preencher</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="455"/>
        <source>Center</source>
        <translation>Centrar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="344"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Especifique se os caracteres da caixa de desenho devem ser desenhados por QTerminal internamente ou manipulados pelas bibliotecas específicas dos tipos de letra.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Alterna a utilização do texto a negrito para cores intensas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="241"/>
        <source>Use bold font face for intense colors</source>
        <translation>Utilizar letra a negrito para cores intensas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Ocultar contornos da janela</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="822"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Define o comportamento a emular. Tenha em atenção que esta definição não tem que ter correspondência com o sistema operativo.&lt;/p&gt;&lt;p&gt;Se você não tiver a certeza, utilize a &lt;span style=&quot; font-weight:600;&quot;&gt;emulação&lt;/span&gt; padrão.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="800"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Este comando será executado com um argumento com um nome do ficheiro temporário que contém o histórico de deslocação</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="803"/>
        <source>Handle history command</source>
        <translation>Lidar com o comando de histórico</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="701"/>
        <location filename="../forms/propertiesdialog.ui" line="715"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="722"/>
        <source>Get current size</source>
        <translation>Obter tamanho atual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="757"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Abrir novo separador à direita do separador ativo</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="754"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Se inativa, o novo separador será aberto à direita do último separador aberto</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="658"/>
        <source>Close tab on middle-click</source>
        <translation>Fechar separador com o botão central do rato</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Desactivar forçosamente o modo de colar com parênteses retos</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="634"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>O modo de colar entre parênteses retos é útil para colar strings de várias linhas.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="764"/>
        <source>Audible bell</source>
        <translation>Campainha audível</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="846"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Para editar um atalho:
1. Clique duas vezes na tecla
2. Prima a combinação desejada
3. Clique no atalho ou prima Enter

Para remover/desativar um atalho, no ponto 2, prima apenas um modificador (como Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="900"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>Um botão de bloqueio é mostrado na barra de separador horizontal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="903"/>
        <source>Keep window open when it loses focus</source>
        <translation>Manter a janela aberta quando perder o foco</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="921"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="931"/>
        <location filename="../forms/propertiesdialog.ui" line="948"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="938"/>
        <source>Width</source>
        <translation>Largura</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1029"/>
        <source>Edit bookmark file contents</source>
        <translation>Editar conteúdo do ficheiro de marcadores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="988"/>
        <source>Enable bookmarks</source>
        <translation>Ativar marcadores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="997"/>
        <source>Bookmark file</source>
        <translation>Ficheiro de marcadores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="893"/>
        <source>Show on start</source>
        <translation>Mostrar ao iniciar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="316"/>
        <source>Change window title based on current terminal</source>
        <translation>Alterar título da janela de acordo com o terminal atual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="323"/>
        <source>Change window icon based on current terminal</source>
        <translation>Alterar ícone da janela de acordo com o terminal atual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="337"/>
        <source>Enable bi-directional text support</source>
        <translation>Ativar suporte a texto bidirecional</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="406"/>
        <source>Background image:</source>
        <translation>Imagem de fundo:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Select</source>
        <translation>Selecionar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="330"/>
        <source>Show terminal size on resize</source>
        <translation>Mostrar tamanho do terminal ao redimensionar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="289"/>
        <location filename="../forms/propertiesdialog.ui" line="507"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="306"/>
        <source>Show close button on each tab</source>
        <translation>Mostrar botão de fecho nos separadores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="910"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="962"/>
        <source>Shortcut:</source>
        <translation>Atalho:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1010"/>
        <source>Find...</source>
        <translation>Localizar...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1019"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Pode especificar a localização do ficheiro de marcadores. Permite a partilha de marcadores através do Own Cloud ou do Dropbox.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="364"/>
        <location filename="../forms/propertiesdialog.ui" line="390"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="876"/>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="881"/>
        <source>Key</source>
        <translation>Tecla</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <source>No scrollbar</source>
        <translation>Sem barra de deslocação</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Top</source>
        <translation>Cima</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Bottom</source>
        <translation>Baixo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>BlockCursor</source>
        <translation>Bloco</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>UnderlineCursor</source>
        <translation>Sublinhado</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>IBeamCursor</source>
        <translation>Ibeam</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>No move</source>
        <translation>Não mover</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to top</source>
        <translation>Deslizar para o topo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to bottom</source>
        <translation>Deslizar para o fundo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="268"/>
        <source>Examples</source>
        <translation>Exemplos</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="421"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Imagens (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="511"/>
        <source>Open bookmarks file</source>
        <translation>Abrir ficheiro de marcadores</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="513"/>
        <source>XML files (*.xml)</source>
        <translation>Ficheiros XML (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="514"/>
        <source>All files (*)</source>
        <translation>Todos os ficheiros (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="613"/>
        <location filename="../propertiesdialog.cpp" line="617"/>
        <source>Question</source>
        <translation>Questão</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="613"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Quer substituir este ficheiro de marcadores?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="617"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>O nome do ficheiro de marcadores não termina com &apos;.xml&apos;.
Tem a certeza de que o quer substituir?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="625"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="625"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>Não é possível gravar marcadores neste ficheiro:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="203"/>
        <location filename="../propertiesdialog.cpp" line="317"/>
        <source>System Default</source>
        <translation>Predefinições</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="420"/>
        <source>Choose a background image</source>
        <translation>Escolha a imagem de fundo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Marcadores sincronizados</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="80"/>
        <location filename="../tabwidget.cpp" line="234"/>
        <source>Shell No. %1</source>
        <translation>Consola n.º %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="202"/>
        <source>Tab name</source>
        <translation>Nome do separador</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="203"/>
        <source>New tab name:</source>
        <translation>Nome do novo separador:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="223"/>
        <source>Select new tab title color</source>
        <translation>Selecione a cor do título do novo separador</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="252"/>
        <source>Close session</source>
        <translation>Fechar sessão</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="254"/>
        <source>Change title color</source>
        <translation>Alterar cor do título</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>Carregar sessão</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>Lista de sessões guardadas:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Janela principal</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Ações</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>Aj&amp;uda</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Acerca...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Acerca de &amp;Qt...</translation>
    </message>
</context>
</TS>
